# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# No Mojolicious prior to Fedora 14
# Mojolicious in Fedora 14 is too old
# No Mojolicious in EPEL
%if 0%{?fedora} > 14
%global have_mojo 1
%else
%global have_mojo 0
%endif

Name:		perl-MIME-Types
Version:	2.13
Release:	3.%{__distinit}%{__distvers}
Summary:	MIME types module for Perl
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/MIME-Types/
Source0:	http://search.cpan.org/CPAN/authors/id/M/MA/MARKOV/MIME-Types-%{version}.tar.gz
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(List::Util)
%if %{have_mojo}
BuildRequires:	perl(Mojo::Base)
%endif
BuildRequires:	perl(overload)
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
# Test Suite
BuildRequires:	perl(lib)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(warnings)
# Extra Tests
BuildRequires:	perl(Test::MinimumVersion)
BuildRequires:	perl(Test::Pod) >= 1.00
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
MIME types are used in many applications, for instance as part of e-mail
and HTTP traffic, to indicate the type of content that is transmitted.

Sometimes detailed knowledge about a mime-type is need; however, this
module only knows about the file-name extensions that relate to some
file-type.  It can also be used to produce the right format: types that
are not registered at IANA need to use 'x-' prefixes.

%if %{have_mojo}
%package -n perl-MojoX-MIME-Types

Summary:	MIME Types for Mojolicious
Group:		Development/Libraries
Requires:	perl-MIME-Types = %{version}-%{release}

%description -n perl-MojoX-MIME-Types
This module is a drop-in replacement for Mojolicious::Types, but with a more
correct handling plus a complete list of types... a huge list of types.

Some methods ignore information they receive: those parameters are accepted
for compatibility with the Mojolicious::Types interface, but should not
contain useful information.

%endif

%prep
%setup -q -n MIME-Types-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} %{buildroot}

%check
make test
make test TEST_FILES="xt/*.t"

%clean
rm -rf %{buildroot}

%files
%doc ChangeLog README
%{perl_vendorlib}/MIME/
%{_mandir}/man3/MIME::Type.3*
%{_mandir}/man3/MIME::Types.3*

%if %{have_mojo}
%files -n perl-MojoX-MIME-Types
%{perl_vendorlib}/MojoX/
%{_mandir}/man3/MojoX::MIME::Types.3*
%else
%exclude %{perl_vendorlib}/MojoX/
%exclude %{_mandir}/man3/MojoX::MIME::Types.3*
%endif

%changelog
* Sat Feb 11 2017 Paul Howarth <paul@city-fan.org> - 2.13-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sat May 21 2016 Paul Howarth <paul@city-fan.org> - 2.13-2
- BR: perl-generators where available

* Tue Mar  8 2016 Paul Howarth <paul@city-fan.org> - 2.13-1
- Update to 2.13
  - Not all information was extracted from the Apache tables
- Simplify find command using -delete

* Thu Feb 11 2016 Paul Howarth <paul@city-fan.org> - 2.12-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Nov 11 2015 Paul Howarth <paul@city-fan.org> - 2.12-1
- Update to 2.12
  - Downgrade prereq perl to 5.6
  - Update IANA

* Fri Jun 26 2015 Paul Howarth <paul@city-fan.org> - 2.11-1
- Update to 2.11
  - Accept field 'q' weights
  - Introduce PERL_MIME_TYPE_DB (CPAN RT#104945)
  - Strict Perl 5.8 (CPAN RT#105267)
- Classify buildreqs by usage

* Mon Sep 15 2014 Paul Howarth <paul@city-fan.org> - 2.09-1
- Update to 2.09
  - Rename ::Type::isAscii() into ::Type::isText()
  - Add source table broofa (CPAN RT#98308)
  - Add source table freedesktop (CPAN RT#98309)
  - Update IANA types
  - Fix scan of freedesktop definitions (CPAN RT#98385)
  - MIME::Type::equals() did cmp not eq
  - New httpAccept() wth tests in t/21accept.t
  - New httpAcceptBest() and httpAcceptSelect() with tests in t/22accbest.t
  - Add MojoX::MIME::Types with tests in t/40mojo.t
  - Now depends on List::Util
  - Documentation fixes
- Sub-package MojoX::MIME::Types to avoid pulling in Mojolicious as a
  dependency for users of MIME::Types
- Drop patch for building with perl < 5.8.8

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> - 2.04-3
- Drop %%defattr, redundant since rpm 4.4

* Thu Sep 12 2013 Paul Howarth <paul@city-fan.org> - 2.04-1
- Update to 2.04:
  - Fix one more localize $_ in ::Types::_read_db() (CPAN RT#87856)

* Wed Sep  4 2013 Paul Howarth <paul@city-fan.org> - 2.03-1
- Update to 2.03:
  - Fix typo in docs (CPAN RT#88394)
  - Require perl 5.8.8, for <:encoding
  - Updated IANA
  - A bit more DESCRIPTION
- Update %%description
- Add patch to drop Perl version requirement back to 5.8.5

* Sun Aug 18 2013 Paul Howarth <paul@city-fan.org> - 2.02-1
- Update to 2.02:
  - Localize DB and $_ in ::Types::_read_db() (CPAN RT#87856)

* Sun Aug  4 2013 Paul Howarth <paul@city-fan.org> - 2.01-1
- Update to 2.01:
  - Add dummy ::Types::create_type_index() because
    Catalyst-Plugin-Static-Simple calls it :(

* Fri Aug  2 2013 Paul Howarth <paul@city-fan.org> - 2.00-1
- Update to 2.00:
  - The mime information is now collected from various sources, amongst them
    IANA; hence, some types may use different x-'s
  - A separate table is built for the extension-to-type mapping
  - Number of types up from 995 to 2096
  - Number of extensions up from 734 to 1425
  - The memory footprint and start-up speed should have improved considerably
  - Added bin/collect_types
  - Fixed some typos (CPAN RT#86847)
  - Added ::Type::isVendor(), ::isExperimental(), ::isPersonal (CPAN RT#87062)
  - Added ::Types::listTypes()
  - Cleaned-up Exporter syntax of (very) old interface
- BR: perl(base), perl(File::Basename) and perl(File::Spec)
- Drop no-longer-needed UTF8 patch

* Fri Jan 11 2013 Paul Howarth <paul@city-fan.org> - 1.38-1
- Update to 1.38:
  - Add application/vnd.ms-excel.template.macroEnabled.12 and five related
    from http://filext.com/faq/office_mime_types.php (CPAN RT#82616)

* Fri Dec 21 2012 Paul Howarth <paul@city-fan.org> - 1.37-1
- Update to 1.37:
  - Remove text/x-perl, where we also have an application/x-perl
    (CPAN RT#82100)

* Thu Nov  1 2012 Paul Howarth <paul@city-fan.org> - 1.36-1
- Update to 1.36:
  - xlsx and friends had encoding 'binary' (since version 1.30), but should
    have been 'base64' (CPAN RT#80529)

* Wed Jun 20 2012 Paul Howarth <paul@city-fan.org> - 1.35-1
- Update to 1.35:
  - Added video/webm and audio/webm, although not (yet) IANA registered
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Fri Jan 13 2012 Paul Howarth <paul@city-fan.org> - 1.34-1
- Update to 1.34:
  - subType() did not handle subType's with '+' in them
- BR: perl(Carp) and perl(Exporter)

* Fri Aug 19 2011 Paul Howarth <paul@city-fan.org> - 1.32-1
- Update to 1.32:
  - Explain how to use MIME::Types in mod_perl; when you do not read the
    documentation about mod_perl/fork it will work as always, but
    inefficiently

* Thu Jun 30 2011 Paul Howarth <paul@city-fan.org> - 1.31-2
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Mar 15 2011 Paul Howarth <paul@city-fan.org> - 1.31-1
- Import from Fedora
- Update to 1.31:
  - Added zillions of new types from debian's /etc/mime.types
  - Changed table format, hopefully to speed-up load times per type, slightly
    compensating for the increased list
  - Fix typo (CPAN RT#55655)
  - xlsx must be encoded binary
  - Added f4v, f4p, f4a, f4b extensions for mpeg4 (CPAN RT#55168)
  - Moved POD test to xt directory, reducing the number of dependencies

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.28-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Dec 20 2010 Marcela Maslanova <mmaslano@redhat.com> - 1.28-4
- Rebuild to fix problems with vendorarch/lib (#661697)

* Mon May 03 2010 Marcela Maslanova <mmaslano@redhat.com> - 1.28-3
- Mass rebuild with perl-5.12.0

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 1.28-2
- Rebuild against perl 5.10.1

* Wed Oct  7 2009 Stepan Kasal <skasal@redhat.com> - 1.28-1
- New upstream version

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.27-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Mar 13 2009 Tom "spot" Callaway <tcallawa@redhat.com> - 1.27-1
- Update to 1.27

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.24-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Nov 20 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.24-1
- Update to 1.24

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.23-3
- Rebuild for perl 5.10 (again)

* Sun Jan 20 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.23-2
- Rebuild for new perl

* Wed Dec 19 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 1.23-1
- Bump to 1.23

* Sun Aug 26 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 1.20-2
- License tag fix

* Wed Jun 13 2007 Ville Skyttä <ville.skytta at iki.fi> - 1.20-1
- 1.20
- Convert docs to UTF-8

* Tue Apr 17 2007 Ville Skyttä <ville.skytta at iki.fi> - 1.19-2
- BuildRequire perl(Test::More)

* Mon Mar 26 2007 Ville Skyttä <ville.skytta at iki.fi> - 1.19-1
- 1.19
- BuildRequire perl(ExtUtils::MakeMaker)

* Wed Nov 22 2006 Ville Skyttä <ville.skytta at iki.fi> - 1.18-1
- 1.18

* Fri Sep 15 2006 Ville Skyttä <ville.skytta at iki.fi> - 1.17-2
- Rebuild

* Tue Aug 15 2006 Ville Skyttä <ville.skytta at iki.fi> - 1.17-1
- 1.17

* Sun Oct  2 2005 Ville Skyttä <ville.skytta at iki.fi> - 1.16-1
- 1.16

* Fri Apr  1 2005 Ville Skyttä <ville.skytta at iki.fi> - 1.15-2
- 1.15

* Tue May 25 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:1.13-0.fdr.3
- Require perl(:MODULE_COMPAT_*) (bug 1649)

* Mon May 17 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:1.13-0.fdr.2
- Sync with IANA 20040517
- Require perl >= 1:5.6.1 for vendor install dir support
- Use pure_install to avoid perllocal.pod workarounds

* Sat Apr 24 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:1.13-0.fdr.1
- Update to 1.13 + IANA 20040424

* Sun Feb  1 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:1.12-0.fdr.2
- Reduce directory ownership bloat

* Wed Jan 21 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:1.12-0.fdr.1
- Update to 1.12

* Wed Jan 14 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:1.11-0.fdr.1
- Update to 1.11

* Wed Dec 31 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:1.10-0.fdr.2
- BuildRequires perl(Test::More)

* Fri Dec 19 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:1.10-0.fdr.1
- Update to 1.10

* Thu Nov  6 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:1.09-0.fdr.1
- Update to 1.09

* Tue Nov  4 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:1.08-0.fdr.1
- Update to 1.08

* Sat Oct 11 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:1.07-0.fdr.2
- Install into vendor dirs
- Don't use fedora-rpm-helper
- Specfile cleanup

* Wed Jul 30 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:1.07-0.fdr.1
- Update to 1.07
- Use fedora-rpm-helper

* Tue Jun 24 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:1.06-0.fdr.1
- First build
